@@ -6,6 +6,7 @@
 
 #include "../schema/column.h"
 #include "../schema/table.h"
+#include "../column_pointer.h"
 
 namespace sqlite_orm {
 #ifdef SQLITE_ENABLE_DBSTAT_VTAB
@@ -35,5 +36,9 @@ namespace sqlite_orm {
                           make_column("pgoffset", &dbstat::pgoffset),
                           make_column("pgsize", &dbstat::pgsize));
     }
+
+#ifdef SQLITE_ORM_WITH_CPP20_ALIASES
+    inline constexpr orm_table_reference auto dbstat_table = c<dbstat>();
+#endif
 #endif  //  SQLITE_ENABLE_DBSTAT_VTAB
 }
