@@ -3,11 +3,13 @@
  *  this file is also used to provide definitions of interface methods 'hitting the database'.
  */
 #pragma once
-#include <type_traits>  //  std::decay_t
+
+#include <type_traits>  //  std::remove_reference
 #include <utility>  //  std::move
 #include <algorithm>  //  std::find_if, std::ranges::find
 
-#include "../functional/cxx_universal.h"  //  ::size_t
+#include "../tuple_helper/tuple_filter.h"
+#include "../type_traits.h"
 #include "../type_printer.h"
 #include "../schema/column.h"
 #include "../schema/table.h"
@@ -20,21 +22,28 @@ namespace sqlite_orm {
             std::vector<table_xinfo> res;
             res.reserve(filter_tuple_sequence_t<elements_type, is_column>::size());
             this->for_each_column([&res](auto& column) {
-                using field_type = field_type_t<std::decay_t<decltype(column)>>;
+                using field_type = field_type_t<std::remove_reference_t<decltype(column)>>;
                 std::string dft;
-                if(auto d = column.default_value()) {
+                if (auto d = column.default_value()) {
                     dft = std::move(*d);
                 }
+                using constraints_tuple = decltype(column.constraints);
+                constexpr bool hasExplicitNull =
+                    mpl::invoke_t<mpl::disjunction<check_if_has_type<null_t>>, constraints_tuple>::value;
+                constexpr bool hasExplicitNotNull =
+                    mpl::invoke_t<mpl::disjunction<check_if_has_type<not_null_t>>, constraints_tuple>::value;
                 res.emplace_back(-1,
                                  column.name,
                                  type_printer<field_type>().print(),
-                                 column.is_not_null(),
+                                 !hasExplicitNull && !hasExplicitNotNull
+                                     ? column.is_not_null()
+                                     : (hasExplicitNull ? !hasExplicitNull : hasExplicitNotNull),
                                  std::move(dft),
                                  column.template is<is_primary_key>(),
                                  column.template is<is_generated_always>());
             });
             auto compositeKeyColumnNames = this->composite_key_columns_names();
-            for(size_t i = 0; i < compositeKeyColumnNames.size(); ++i) {
+            for (size_t i = 0; i < compositeKeyColumnNames.size(); ++i) {
                 const std::string& columnName = compositeKeyColumnNames[i];
 #if __cpp_lib_ranges >= 201911L
                 auto it = std::ranges::find(res, columnName, &table_xinfo::name);
@@ -43,7 +52,7 @@ namespace sqlite_orm {
                     return ti.name == columnName;
                 });
 #endif
-                if(it != res.end()) {
+                if (it != res.end()) {
                     it->pk = static_cast<int>(i + 1);
                 }
             }
