@@ -1,15 +1,18 @@
 #pragma once
 
 #include <sqlite3.h>
+#include <cstdlib>  // atoi
 #include <string>  //  std::string
 #include <functional>  //  std::function
 #include <memory>  // std::shared_ptr
 #include <vector>  //  std::vector
 #include <sstream>
+#include <iomanip>  //  std::flush
 
 #include "error_code.h"
 #include "row_extractor.h"
 #include "journal_mode.h"
+#include "locking_mode.h"
 #include "connection_holder.h"
 #include "util.h"
 #include "serializing_util.h"
@@ -29,7 +32,7 @@ namespace sqlite_orm {
             auto& res = *(std::vector<std::string>*)data;
             res.reserve(argc);
             const auto rowExtractor = column_text_extractor<std::string>();
-            for(int i = 0; i < argc; ++i) {
+            for (int i = 0; i < argc; ++i) {
                 auto rowString = rowExtractor.extract(argv[i]);
                 res.push_back(std::move(rowString));
             }
@@ -61,14 +64,22 @@ namespace sqlite_orm {
                 return this->get_pragma<int>("busy_timeout");
             }
 
+            sqlite_orm::locking_mode locking_mode() {
+                return this->get_pragma<sqlite_orm::locking_mode>("locking_mode");
+            }
+
+            void locking_mode(sqlite_orm::locking_mode value) {
+                this->set_pragma("locking_mode", value);
+            }
+
             sqlite_orm::journal_mode journal_mode() {
                 return this->get_pragma<sqlite_orm::journal_mode>("journal_mode");
             }
 
             void journal_mode(sqlite_orm::journal_mode value) {
-                this->_journal_mode = -1;
+                this->journal_mode_ = -1;
                 this->set_pragma("journal_mode", value);
-                this->_journal_mode = static_cast<decltype(this->_journal_mode)>(value);
+                this->journal_mode_ = static_cast<decltype(this->journal_mode_)>(value);
             }
 
             /**
@@ -90,9 +101,9 @@ namespace sqlite_orm {
             }
 
             void synchronous(int value) {
-                this->_synchronous = -1;
+                this->synchronous_ = -1;
                 this->set_pragma("synchronous", value);
-                this->_synchronous = value;
+                this->synchronous_ = value;
             }
 
             int user_version() {
@@ -111,6 +122,14 @@ namespace sqlite_orm {
                 this->set_pragma("auto_vacuum", value);
             }
 
+            int max_page_count() {
+                return this->get_pragma<int>("max_page_count");
+            }
+
+            void max_page_count(int value) {
+                this->set_pragma("max_page_count", value);
+            }
+
             std::vector<std::string> integrity_check() {
                 return this->get_pragma<std::vector<std::string>>("integrity_check");
             }
@@ -146,16 +165,16 @@ namespace sqlite_orm {
                     ss.str(),
                     [](void* data, int argc, char** argv, char**) -> int {
                         auto& res = *(std::vector<sqlite_orm::table_xinfo>*)data;
-                        if(argc) {
+                        if (argc) {
                             auto index = 0;
-                            auto cid = std::atoi(argv[index++]);
+                            auto cid = atoi(argv[index++]);
                             std::string name = argv[index++];
                             std::string type = argv[index++];
-                            bool notnull = !!std::atoi(argv[index++]);
+                            bool notnull = !!atoi(argv[index++]);
                             std::string dflt_value = argv[index] ? argv[index] : "";
                             ++index;
-                            auto pk = std::atoi(argv[index++]);
-                            auto hidden = std::atoi(argv[index++]);
+                            auto pk = atoi(argv[index++]);
+                            auto hidden = atoi(argv[index++]);
                             res.emplace_back(cid,
                                              std::move(name),
                                              std::move(type),
@@ -183,15 +202,15 @@ namespace sqlite_orm {
                     ss.str(),
                     [](void* data, int argc, char** argv, char**) -> int {
                         auto& res = *(std::vector<sqlite_orm::table_info>*)data;
-                        if(argc) {
+                        if (argc) {
                             auto index = 0;
-                            auto cid = std::atoi(argv[index++]);
+                            auto cid = atoi(argv[index++]);
                             std::string name = argv[index++];
                             std::string type = argv[index++];
-                            bool notnull = !!std::atoi(argv[index++]);
+                            bool notnull = !!atoi(argv[index++]);
                             std::string dflt_value = argv[index] ? argv[index] : "";
                             ++index;
-                            auto pk = std::atoi(argv[index++]);
+                            auto pk = atoi(argv[index++]);
                             res.emplace_back(cid, std::move(name), std::move(type), notnull, std::move(dflt_value), pk);
                         }
                         return 0;
@@ -203,8 +222,8 @@ namespace sqlite_orm {
           private:
             friend struct storage_base;
 
-            int _synchronous = -1;
-            signed char _journal_mode = -1;  //  if != -1 stores static_cast<sqlite_orm::journal_mode>(journal_mode)
+            int synchronous_ = -1;
+            signed char journal_mode_ = -1;  //  if != -1 stores static_cast<sqlite_orm::journal_mode>(journal_mode)
             get_connection_t get_connection;
 
             template<class T>
@@ -221,23 +240,29 @@ namespace sqlite_orm {
              */
             template<class T>
             void set_pragma(const std::string& name, const T& value, sqlite3* db = nullptr) {
-                auto con = this->get_connection();
-                if(!db) {
-                    db = con.get();
-                }
                 std::stringstream ss;
-                ss << "PRAGMA " << name << " = " << value << std::flush;
-                perform_void_exec(db, ss.str());
+                ss << "PRAGMA " << name << " = " << value;
+                this->set_pragma_impl(ss.str(), db);
             }
 
-            void set_pragma(const std::string& name, const sqlite_orm::journal_mode& value, sqlite3* db = nullptr) {
+            void set_pragma(const std::string& name, sqlite_orm::journal_mode value, sqlite3* db = nullptr) {
+                std::stringstream ss;
+                ss << "PRAGMA " << name << " = " << journal_mode_to_string(value);
+                this->set_pragma_impl(ss.str(), db);
+            }
+
+            void set_pragma(const std::string& name, sqlite_orm::locking_mode value, sqlite3* db = nullptr) {
+                std::stringstream ss;
+                ss << "PRAGMA " << name << " = " << locking_mode_to_string(value);
+                this->set_pragma_impl(ss.str(), db);
+            }
+
+            void set_pragma_impl(const std::string& query, sqlite3* db = nullptr) {
                 auto con = this->get_connection();
-                if(!db) {
+                if (db == nullptr) {
                     db = con.get();
                 }
-                std::stringstream ss;
-                ss << "PRAGMA " << name << " = " << to_string(value) << std::flush;
-                perform_void_exec(db, ss.str());
+                perform_void_exec(db, query);
             }
         };
     }
