@@ -2,7 +2,6 @@
 
 #include <string>  //  std::string
 
-#include "functional/cxx_universal.h"  //  ::size_t
 #include "functional/static_magic.h"
 #include "functional/index_sequence_util.h"
 #include "tuple_helper/tuple_traits.h"
@@ -11,6 +10,8 @@
 #include "type_traits.h"
 #include "select_constraints.h"
 #include "cte_types.h"
+#include "schema/column.h"
+#include "schema/table.h"
 #include "storage_lookup.h"
 
 // interface functions
@@ -42,7 +43,7 @@ namespace sqlite_orm {
          *  Find column name by its type and member pointer.
          */
         template<class O, class F, class DBOs, satisfies<is_db_objects, DBOs> = true>
-        const std::string* find_column_name(const DBOs& dbObjects, F O::*field) {
+        const std::string* find_column_name(const DBOs& dbObjects, F O::* field) {
             return pick_table<O>(dbObjects).find_column_name(field);
         }
 
@@ -56,7 +57,7 @@ namespace sqlite_orm {
             return cp.field;
         }
 
-#if(SQLITE_VERSION_NUMBER >= 3008003) && defined(SQLITE_ORM_WITH_CTE)
+#if (SQLITE_VERSION_NUMBER >= 3008003) && defined(SQLITE_ORM_WITH_CTE)
         /**
          *  Materialize column pointer:
          *  3. by moniker and alias_holder<>.
@@ -92,7 +93,7 @@ namespace sqlite_orm {
             return pick_table<O>(dbObjects).find_column_name(field);
         }
 
-#if(SQLITE_VERSION_NUMBER >= 3008003) && defined(SQLITE_ORM_WITH_CTE)
+#if (SQLITE_VERSION_NUMBER >= 3008003) && defined(SQLITE_ORM_WITH_CTE)
         /**
          *  Find column name by:
          *  3. by moniker and alias_holder<>.
