@@ -1,9 +1,8 @@
 #pragma once
 
 #include <type_traits>  //  std::integral_constant, std::index_sequence, std::conditional, std::declval
-#include <tuple>  //  std::tuple
+#include <tuple>  //  std::tuple, std::tuple_cat, std::tuple_element
 
-#include "../functional/cxx_universal.h"  //  ::size_t
 #include "../functional/mpl/conditional.h"
 #include "../functional/index_sequence_util.h"
 
@@ -61,8 +60,7 @@ namespace sqlite_orm {
          *  `FilterProj` is a metafunction
          */
         template<class Tpl,
-                 template<class...>
-                 class Pred,
+                 template<class...> class Pred,
                  template<class...> class FilterProj = polyfill::type_identity_t,
                  class Seq = std::make_index_sequence<std::tuple_size<Tpl>::value>>
         using filter_tuple_sequence_t = typename filter_tuple_sequence<Tpl, Pred, FilterProj, Seq>::type;
@@ -72,8 +70,7 @@ namespace sqlite_orm {
          *  `FilterProj` is a metafunction
          */
         template<class Tpl,
-                 template<class...>
-                 class Pred,
+                 template<class...> class Pred,
                  template<class...> class FilterProj = polyfill::type_identity_t,
                  class Seq = std::make_index_sequence<std::tuple_size<Tpl>::value>>
         using filter_tuple_t = tuple_from_index_sequence_t<Tpl, filter_tuple_sequence_t<Tpl, Pred, FilterProj, Seq>>;
@@ -88,8 +85,7 @@ namespace sqlite_orm {
          *  with a default Sequence in function template parameters [SQLITE_ORM_BROKEN_VARIADIC_PACK_EXPANSION].
          */
         template<class Tpl,
-                 template<class...>
-                 class Pred,
+                 template<class...> class Pred,
                  class Seq,
                  template<class...> class FilterProj = polyfill::type_identity_t>
         struct count_filtered_tuple
