@@ -35,24 +35,24 @@ int main(int, char**) {
     storage.insert(MarvelHero{-1, "Natasha Romanoff", "Black widow"});
     storage.insert(MarvelHero{-1, "Groot", "I am Groot!"});
 
-    cout << "Heros count = " << storage.count<MarvelHero>() << endl;
+    cout << "Heroes count = " << storage.count<MarvelHero>() << endl;
 
-    //  iterate through heros - iteration takes less memory than `get_all` because
+    //  iterate through heroes - iteration takes less memory than `get_all` because
     //  iteration fetches row by row once it is needed. If you break at any iteration
     //  statement will be cleared without fetching remaining rows.
-    for(auto& hero: storage.iterate<MarvelHero>()) {
+    for (auto& hero: storage.iterate<MarvelHero>()) {
         cout << "hero = " << storage.dump(hero) << endl;
     }
 
     cout << "====" << endl;
 
     //  one can iterate with custom WHERE conditions..
-    for(auto& hero: storage.iterate<MarvelHero>(where(c(&MarvelHero::name) == "Thor"))) {
+    for (auto& hero: storage.iterate<MarvelHero>(where(c(&MarvelHero::name) == "Thor"))) {
         cout << "hero = " << storage.dump(hero) << endl;
     }
 
-    cout << "Heros with LENGTH(name) < 6 :" << endl;
-    for(auto& hero: storage.iterate<MarvelHero>(where(length(&MarvelHero::name) < 6))) {
+    cout << "Heroes with LENGTH(name) < 6 :" << endl;
+    for (auto& hero: storage.iterate<MarvelHero>(where(length(&MarvelHero::name) < 6))) {
         cout << "hero = " << storage.dump(hero) << endl;
     }
 
@@ -68,7 +68,7 @@ int main(int, char**) {
     cout << "====" << endl;
 
     cout << "Distinct hero names:" << endl;
-    for(std::string name: storage.iterate(select(distinct(&MarvelHero::name)))) {
+    for (std::string name: storage.iterate(select(distinct(&MarvelHero::name)))) {
         cout << name << endl;
     }
 #endif
