@@ -20,7 +20,22 @@ TEST_CASE("recursive_triggers") {
     REQUIRE(result);
 }
 
-TEST_CASE("Journal mode") {
+TEST_CASE("locking_mode") {
+    auto storage = make_storage("");
+
+    SECTION("EXCLUSIVE") {
+        storage.pragma.locking_mode(locking_mode::EXCLUSIVE);
+        const auto result = storage.pragma.locking_mode();
+        REQUIRE(result == locking_mode::EXCLUSIVE);
+    }
+    SECTION("NORMAL") {
+        storage.pragma.locking_mode(locking_mode::NORMAL);
+        const auto result = storage.pragma.locking_mode();
+        REQUIRE(result == locking_mode::NORMAL);
+    }
+}
+
+TEST_CASE("journal_mode") {
     auto filename = "journal_mode.sqlite";
     ::remove(filename);
     auto storage = make_storage(filename);
@@ -35,15 +50,15 @@ TEST_CASE("Journal mode") {
     auto jm = stor->pragma.journal_mode();
     REQUIRE(jm == journal_mode::DELETE);
 
-    for(auto i = 0; i < 2; ++i) {
-        if(i == 0) {
+    for (auto i = 0; i < 2; ++i) {
+        if (i == 0) {
             stor->begin_transaction();
         }
         stor->pragma.journal_mode(journal_mode::MEMORY);
         jm = stor->pragma.journal_mode();
         REQUIRE(jm == journal_mode::MEMORY);
 
-        if(i == 1) {  //  WAL cannot be set within a transaction
+        if (i == 1) {  //  WAL cannot be set within a transaction
             stor->pragma.journal_mode(journal_mode::WAL);
             jm = stor->pragma.journal_mode();
             REQUIRE(jm == journal_mode::WAL);
@@ -62,7 +77,7 @@ TEST_CASE("Journal mode") {
         jm = stor->pragma.journal_mode();
         REQUIRE(jm == journal_mode::TRUNCATE);
 
-        if(i == 0) {
+        if (i == 0) {
             stor->rollback();
         }
     }
@@ -80,7 +95,7 @@ TEST_CASE("Synchronous") {
     try {
         storage.pragma.synchronous(newValue);
         throw std::runtime_error("Must not fire");
-    } catch(const std::system_error&) {
+    } catch (const std::system_error&) {
         //  Safety level may not be changed inside a transaction
         REQUIRE(storage.pragma.synchronous() == value);
     }
