@@ -336,8 +336,8 @@ TEST_CASE("Transaction guard") {
         auto guard2 = storage2.transaction_guard();
         storage2.get_all<Object>();
 
-        alignas(alignof(internal::transaction_guard_t)) char buffer[sizeof(internal::transaction_guard_t)];
-        auto guard = new(&buffer) internal::transaction_guard_t{storage.transaction_guard()};
+        alignas(internal::transaction_guard_t) char buffer[sizeof(internal::transaction_guard_t)];
+        auto guard = new (&buffer) internal::transaction_guard_t{storage.transaction_guard()};
         storage.insert<Object>({});
         guard->commit_on_destroy = true;
         REQUIRE_THROWS_WITH(guard->~transaction_guard_t(), ContainsSubstring("database is locked"));
